package models

import (
	"github.com/beego/beego/v2/client/orm"
	"time"
)

type CygxActivitySpecialSignup struct {
	Id          int       `orm:"column(id);pk"`
	ActivityId  int       `description:"活动ID"`
	UserId      int       `description:"用户ID"`
	CreateTime  time.Time `description:"创建时间"`
	Mobile      string    `description:"手机号"`
	Email       string    `description:"邮箱"`
	CompanyId   int       `description:"公司id"`
	CompanyName string    `description:"公司名称"`
	RealName    string    `description:"用户实际名称"`
	SellerName  string    `description:"所属销售"`
}

type SignupSpecialStatus struct {
	ActivityId    int    `description:"活动ID"`
	HasPermission int    `description:"操作方式，1:有该行业权限,正常展示，2：无该行业权限，3：潜在客户，未提交过申请，4：潜在客户,已提交过申请"`
	PopupMsg      string `description:"权限弹窗信息"`
	Status        int    `description:"返回类型，1:添加，2：取消"`
	SellerMobile  string `description:"销售电话"`
	SellerName    string `description:"销售姓名"`
}

//添加
func AddCygxActivitySpecialSignup(item *CygxActivitySpecialSignup) (err error) {
	o := orm.NewOrm()
	_, err = o.Insert(item)
	return
}

//获取某一用户的报名的数量
func GetUserCygxActivitySpecialSignup(uid, activityId int) (count int, err error) {
	sqlCount := `SELECT COUNT(1) AS count FROM cygx_activity_special_signup  WHERE  user_id=?  AND   activity_id =? `
	o := orm.NewOrm()
	err = o.Raw(sqlCount, uid, activityId).QueryRow(&count)
	return
}

//删除
func DeleteCygxActivitySpecialSignup(uid, activityId int) (err error) {
	o := orm.NewOrm()
	sql := `DELETE  FROM cygx_activity_special_signup   WHERE   user_id=?   AND  activity_id=?    `
	_, err = o.Raw(sql, uid, activityId).Exec()
	return
}

//列表
func GetActivityListSpecialAll(activityId int) (items []*CygxActivitySpecialSignup, err error) {
	o := orm.NewOrm()
	sql := `SELECT art.*  FROM cygx_activity_special_signup as art WHERE 1= 1 AND  activity_id = ?  GROUP BY company_id`
	_, err = o.Raw(sql, activityId).QueryRows(&items)
	return
}
